Python3 implementation of SATL
==============================

[![Docs Status](https://readthedocs.org/projects/satl/badge/)](https://readthedocs.org/projects/satl/badge/)

SATL stands for 'Simple APDU Transport Layer'. It is a simple way to exchange ISO7816-4 APDUs over interfaces not covered in ISO7816-3.

More info about SATL here: https://github.com/sebastien-riou/SATL

Python3 package documentation: https://satl.readthedocs.io/en/latest/
